summaryrefslogtreecommitdiffstats
path: root/kioslave/trash/kio_trash.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:17:06 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-20 00:17:06 -0600
commite4e0479220e9e9616b68b2a11e42cff7a8af7b3d (patch)
tree8e01571cdd132dad34ebec38b12c2dbc37d05bd9 /kioslave/trash/kio_trash.cpp
parentd41050ea3f6904e5156d35f664346b816b9e4d12 (diff)
downloadtdebase-e4e0479220e9e9616b68b2a11e42cff7a8af7b3d.tar.gz
tdebase-e4e0479220e9e9616b68b2a11e42cff7a8af7b3d.zip
Rename KApplication to TDEApplication to avoid conflicts with KDE4
Diffstat (limited to 'kioslave/trash/kio_trash.cpp')
-rw-r--r--kioslave/trash/kio_trash.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kioslave/trash/kio_trash.cpp b/kioslave/trash/kio_trash.cpp
index e8bd00792..edd0c372e 100644
--- a/kioslave/trash/kio_trash.cpp
+++ b/kioslave/trash/kio_trash.cpp
@@ -53,12 +53,12 @@ extern "C" {
int KDE_EXPORT kdemain( int argc, char **argv )
{
//KInstance instance( "kio_trash" );
// KApplication is necessary to use kio_file
putenv(strdup("SESSION_MANAGER="));
- KApplication::disableAutoDcopRegistration();
+ TDEApplication::disableAutoDcopRegistration();
TDECmdLineArgs::init(argc, argv, "kio_trash", 0, 0, 0, 0);
TDECmdLineArgs::addCmdLineOptions( options );
- KApplication app( false, false );
+ TDEApplication app( false, false );
TDECmdLineArgs *args = TDECmdLineArgs::parsedArgs();
TrashProtocol slave( args->arg(0), args->arg(1), args->arg(2) );
@@ -53,12 +53,12 @@ extern "C" {
{
//KInstance instance( "kio_trash" );
- // KApplication is necessary to use kio_file
+ // TDEApplication is necessary to use kio_file
putenv(strdup("SESSION_MANAGER="));